\(\varphi_n^*\) for \(p=1\) and arbitray \(q\).
Usage
phi_n_star_mv(X, B, alpha, h1 = 0.14, h2 = 0.14)
Arguments
- X
numeric array of dims (N, M, q)
- B
numeric value for the amount of randomization iterations
- alpha
significance level, has to be numeric value in \((0,1]\)
- h1
numeric positive value for kernel bandwidth along column axis
- h2
numeric positive value for kernel bandwidth along row axis